@@ -20,6 +20,8 @@ class GhettoApi:
         self.lis_btn_dict = None
         self.rec_btn_dict = None
         self.radios_in_view_dict = None
+        self.ghetto_radios_metadata_text = None
+        self.ghetto_dict_error = None
         self.ghetto_measure_dict = None
         self.ghetto_audio_stream_dict = None
         self.ghetto_show_analyser = True
@@ -33,9 +35,18 @@ class GhettoApi:
     def init_rec_btn_dict(self, rec_btn_dict):
         self.rec_btn_dict = rec_btn_dict
 
+    """key:db id, val: radio name shown on html"""
     def init_radios_in_view(self, radios_in_view_dict):
         self.radios_in_view_dict = radios_in_view_dict
 
+    """key:radio name, val: text from metadata"""
+    def init_ghetto_radios_metadata_text(self, ghetto_radios_metadata_text):
+        self.ghetto_radios_metadata_text = ghetto_radios_metadata_text
+
+    """key:radio name, val: error"""
+    def init_ghetto_dict_error(self, ghetto_dict_error):
+        self.ghetto_dict_error = ghetto_dict_error
+
     """"show meta data"""
     def init_ghetto_measurements(self, ghetto_measure_dict):
         self.ghetto_measure_dict = ghetto_measure_dict
