@@ -144,7 +144,7 @@ def make_db_from_schema():
         "INSERT INTO posts (title, content, download_path, pic_comment, pic_content_type, pic_data) VALUES (?, ?, ?, "
         "?, ?, ?)",
         ('relax',
-         'http://5.39.86.44:8006/stream-mp3-CoolCoffee_autodj',
+         'https://listen.openstream.co/6781/audio',
          save_parent_folder,
          '',
          "image/jpeg",
@@ -180,7 +180,16 @@ def make_db_from_schema():
          "image/png",
          convert_ascii(static_images + "radio3d-style-white-neongreen_120x200.png"))
         )
-
+    cur.execute(
+        "INSERT INTO posts (title, content, download_path, pic_comment, pic_content_type, pic_data) VALUES (?, ?, ?, "
+        "?, ?, ?)",
+        ('B2',
+         'https://radiob2-national.cast.addradio.de/radiob2/national/mp3/high/stream.mp3?ar-distributor=ffa0',
+         save_parent_folder,
+         'german (deutsch) only',
+         "image/png",
+         convert_ascii(static_images + "radio3d-style-white-violet_120x200.png"))
+        )
     connection.commit()
     connection.close()
 
