@@ -1,530 +1,147 @@
-var audioContext, audioSource, analyser, analyserRandom, canvas_ctx;
-var requestIdAnimationFrame;
+const pageCover = document.getElementById("pageCover");
+const pageCoverCanvas = document.getElementById("pageCoverCanvas");
+const pageCoverCanvasCtx = pageCoverCanvas.getContext('2d');
+const canvasMaster = document.getElementById("canvasMaster");
+const canvasMasterCtx = canvasMaster.getContext('2d');
+const currentRadioName = document.getElementById('currentRadioName');
+const fileUpload = document.getElementById("fileUpload");
+const localHostSoundRoute = "http://localhost:5050/sound/"
+const playBtn = document.getElementById("playBtn");
+const pauseBtn = document.getElementById("pauseBtn");
+const audio = document.getElementById("audioWithControls");
+const audioVolumeController = document.getElementById("audioVolumeController");
+const audioGainController = document.getElementById("audioGainController");
+
+var audioContext, audioSource, analyserNode, gainNode, analyserRandom;
 var spectrumAnalyserActive = false;
 var spectrumAnalyserShow = false;
 
+
 function setAudioContextVisual() {
-    audio = document.getElementById("audio_with_controls");
     audioContext = new AudioContext();
+    gainNode = audioContext.createGain();
+    analyserNode = audioContext.createAnalyser();
     audioSource = audioContext.createMediaElementSource(audio);
-    analyser = audioContext.createAnalyser();
-    audioSource.connect(analyser).connect(audioContext.destination);
-    // const prime_button = document.querySelectorAll('.btn-primary');
-    // prime_button.forEach(btn => btn.removeEventListener('click',setAudioContextVisual, false));
+    audioSource.connect(analyserNode).connect(gainNode).connect(audioContext.destination)
 }
 ;
-function remove_page_cover() {
+
+function countUpDownInclusiveInt(min, max) {
+
+    if (animatedFunctionTimer >= max) {direction = 0;}
+    if (animatedFunctionTimer <= min ) {direction = 1;}
+    if (direction == 1) {animatedFunctionTimer++;}
+    if (direction == 0) {animatedFunctionTimer--;}
+    return animatedFunctionTimer;
+}
+;
+
+function removePageCover() {
+    stopVisualise();
+    pageCover.style.display = "none";
+    pageCoverCanvas.style.display = "none";
     setAudioContextVisual();
-    document.getElementById("page_cover").style.display = "none";
-};
+}
+;
 
-$(document).ready(function () {
-    // mouseover not accepted
-    document.getElementById('page_cover').addEventListener('click', remove_page_cover);
+function setAudioVolume() {
+    audio.volume = audioVolumeController.value / 100;
+}
+;
 
-    cookieStuff();
-    // is_play_station();
-    cookie_start_set_text_show_visuals();
-    setInterval(delete_info, 2505);
-    setInterval(meta_info, 5004);
-    setInterval(toggle_show_select_box, 5003);
-    setInterval(updateMasterprogress, 5002);
-    setInterval(updateDisplay, 5001);
+function setAudioGain() {
+    gainNode.gain.value = audioGainController.value;
+}
+;
 
-    const canvas = document.getElementById("canvas_master");
-    const file_upload = document.getElementById("fileupload");
-    const local_host_sound_route = "http://localhost:5050/sound/"
-    const play_btn = document.getElementById("play_btn");
-    const pause_btn = document.getElementById("pause_btn");
-    const audio = document.getElementById("audio_with_controls");
-    audio.volume = 0.25;
-    const audio_volume_control = document.getElementById("audio_volume_controller");
+function stopVisualise(e) {    // had to insert this event
+    try {
+        window.cancelAnimationFrame(requestIdAnimationFrame);
+    } catch (error) { console.error(error); }
+    try {
+        window.cancelAnimationFrame(requestIdFieldAnimation);
+    } catch (error) { console.error(error); }
+    requestIdFieldAnimation = undefined;
+    requestIdAnimationFrame = undefined;
+    spectrumAnalyserActive = false;
+}
+;
 
-    audio.addEventListener("play", function () {
-        play_btn.style.display = "none";
-        pause_btn.style.display = "block";
-        pause_btn.style.cursor = "pointer";
-        pause_btn.style.cursor = "hand";
-        $("#pause_btn").on('click', function () {
-            audio.pause();
-        });
-    });
-    audio.addEventListener("pause", function () {
-        play_btn.style.display = "block";
-        pause_btn.style.display = "none";
-        play_btn.style.cursor = "pointer";
-        play_btn.style.cursor = "hand";
-        $("#play_btn").on('click', function () {
-            audio.play();
-        });
-    });
+function reloadAudioElement(newAudioSource, isPlayList) {
 
-    audio_volume_control.addEventListener("input", setAudioVolume);
-
-    file_upload.addEventListener("change", function () {
-        var audio_duration;
-        const playlist_title = document.getElementById("playlist_title");
-        const playlist_section = document.getElementById("playlist_section");
-        playlist_title.style.display = "block";
-        playlist_section.style.display = "block";
-
-        document.getElementById('lbl_div_audio').innerText = "local playlist"; /*current_station.substring(0, 20)*/
-        document.getElementById('lbl_div_audio').style.cursor = "pointer";
-        document.getElementById('lbl_div_audio').style.cursor = "hand";
-        $("#lbl_div_audio").on('click', function () {
-            document.getElementById('file_list').scrollIntoView({ behavior: "smooth" });
-        });
-
-        // console.log(this.files);
-        const files = this.files;
-
-        const clone_files = [...files];
-        const audio = document.getElementById("audio_with_controls");
-        const checkbox_shuffle = document.getElementById('checkbox_shuffle');
-        var fileList = [];
-        for (let i = 0; i < file_upload.files.length; i++) {
-            fileList.push(file_upload.files[i]);
-        }
-        var play_list;
-        play_list = fileList // for non shuffled
-        if (checkbox_shuffle.checked) {
-            // play_list = shuffle_array(fileList);    // destroys fileList org.
-            play_list = shuffle_array(clone_files);
-        }
-        audio.src = URL.createObjectURL(play_list[0]);
-        playlist_title.value = play_list[0].name;
-
-        /*
-    calculateMediaDuration(audio).then(() => {
-        console.log(audio.duration);
-    });
-    */
-		stopVisualiseAudio();
-
-        if (!spectrumAnalyserActive) {
-            analyserRandom = Math.round(Math.random() * 1 + 1);
-            visualiseAudio(null);
-            spectrumAnalyserActive = true;
-        }
-        audio.load();
-        audio.play;
-        // setTimeout(() => {
-        //     audio.pause();
-        //     audio.currentTime = Number.MAX_SAFE_INTEGER; // chrome bug; NaN, infinity
-        // }, audio_duration);
-        if (!spectrumAnalyserActive) {
-            visualiseAudio(null);
-            spectrumAnalyserActive = true;
-        }
-        let track = 1;
-        audio.onended = function () {
-            if (track < play_list.length) {
-                audio.src = "";   // remove from mem
-                audio.currentTime = 0;
-                audio.srcObject = null;
-                audio.src = URL.createObjectURL(play_list[track]);
-                playlist_title.value = play_list[track].name;
-                audio.load();
-                audio.play();
-
-                track++;
-            }
-        }
-
-    });  // file_up
-
-    function is_play_station() {
-        let req = $.ajax({
-            type: 'GET',
-            dataType: "json",
-            url: "/is_play_station"
-        });
-        req.done(function (data) {
-
-            let player_id = data.is_play_station_id;
-            let player_name = data.is_play_station_name;
-            if (player_id !== '-empty-') {
-                audio.src = local_host_sound_route + player_name;
-                audio.load();
-                audio.play();
-                if (!spectrumAnalyserActive) {
-                    visualiseAudio(null);
-                    spectrumAnalyserActive = true;
-                }
-            }
-        });
+    if (!isPlayList) {
+        audio.volume = 0.25;
+        audioVolumeController.value = 25;
+        gainNode.gain.value = 1
+        audioGainController.value = 1;
     }
-    ;
+    audio.src = "";
+    audio.currentTime = 0;
+    audio.srcObject = null;
+    audio.src = newAudioSource;
+    audio.load();
+    audio.play();
 
-    function setAudioVolume() {
-        audio.volume = audio_volume_control.value / 100;
-    }
-    ;
+    selectSpectrumAnalyser();
+}
+;
 
-    $("button").click(function () {
+function randomOne() {
+    return Math.random() >= 0.5 ? 1: -1;
+}
+;
 
-        if ($(this).attr("class") === "navbar-toggle collapsed") {
+function updateDisplay() {
+    var req;
 
-            return;
+    req = $.ajax({
+        type: 'GET',
+        url: "/display_info",
+        cache: false
+    });
+
+    req.done(function (data) {
+        let displays_dict = data.result
+        $.each(displays_dict, function (idx, val) {
+            let radioId = idx;
+            let textInfo = val;
+            try {
+                document.getElementById("Display_" + radioId).value = textInfo;
+            } catch (error) { console.error(error); }
+        });
+    });
+}
+;
+
+function updateMasterprogress() {
+    var req;
+
+    req = $.ajax({
+        type: 'POST',
+        url: "/index_posts_percent",
+        cache: false,
+        data: { 'percent': 'percent' }
+    });
+
+    req.done(function (data) {
+        var percent = '';
+
+        percent = data.result;
+        if (percent === 0) {
+            $('.progress-bar').css('width', 25 + '%').attr('aria-valuenow', 25).html('Timer Off');
         }
-        ;
-
-        let clicked = $(this).attr("name");
-        console.log("send name " + clicked);
-        let class_val = $(this).attr("class");
-        console.log("send button " + class_val);
-        let id = $(this).attr("id");
-        let dict = {
-            'name': clicked,
-            'class_val': class_val,
-            'button_id': id
-
-        };
-        req = $.ajax({
-            type: 'POST',
-            dataType: "json",
-            url: "/",
-            data: dict
-        });
-        $('#' + id).fadeOut(1).fadeIn(3);
-
-        req.done(function (data) {
-
-            if (data.class_val === "btn btn-primary") {
-                $('#' + id).removeClass("btn btn-primary");
-                $('#' + id).addClass("btn btn-danger");
+        if (percent !== 0) {
+            $('.progress-bar').css('width', percent + '%').attr('aria-valuenow', percent).html('Run, Forrest! RUN!');
+            if (percent >= 100) {
+                window.location.href = "/page_flash";
             }
-            ;
-
-            if (data.class_val === "btn btn-danger") {
-                $('#' + id).removeClass("btn btn-danger");
-                $('#' + id).addClass("btn btn-primary");
-            }
-            ;
-
-            if (data.streamer) {
-                /* Del all streamer, push current in combo box */
-                cookie_set_streamer();
-                $('#cacheList').find('option:not(:first)').remove();
-                let streamer = data.streamer.split(",");
-
-                $.each(streamer, function (idx, val) {
-
-                    let stream = val;
-                    if (stream.length !== 0) {
-                        stream = val.split("=");
-                        let table_id = stream[1];
-                        let title = stream[0];
-                        cacheListFeed(table_id, title);
-
-                        if (data.streamer === 'empty_json') {
-                            $('#cacheList').find('option:not(:first)').remove();
-                            document.getElementById('cacheList').style.color = "#696969";
-                            document.getElementById('cacheList').style.textColor = "#696969";
-                            cookie_del_streamer();
-                        }
-                        console.log('data.streamer ' + data.streamer);
-
-                    }
-
-                });    /*each*/
-
-            }
-            ;
-
-            if (data.radio_table_id) {
-
-            }
-            ;
-
-            /* current play station */
-
-            if (data.table_ident) {
-
-                var current_station = data.table_ident;
-                console.log('table_ident ' + current_station);
-
-                if (current_station !== 'Null') {
-
-                    cookie_set_station(current_station, id);
-
-                    document.getElementById('lbl_div_audio').innerText = current_station; /*current_station.substring(0, 20)*/
-                    document.getElementById('lbl_div_audio').style.cursor = "pointer";
-                    document.getElementById('lbl_div_audio').style.cursor = "hand";
-                    $("#lbl_div_audio").on('click', function () {
-                        document.getElementById('dot_' + id).scrollIntoView({ behavior: "smooth" });
-                    });
-
-                }
-                if (data.former_button_to_switch) {
-                    let num = data.former_button_to_switch;
-                    console.log('auto_click former_button_to_switch: ' + num);
-                    $("#" + num).click();
-                }
-                ;
-            }
-            ;
-
-            if (data.result === 'deactivate_audio') {
-                console.log('deactivate_audio');
-                audio.src = "";
-                audio.currentTime = 0;
-                audio.srcObject = null;
-                document.getElementById('lbl_div_audio').innerText = '';
-                cookie_del_station();
-            }
-            ;
-
-            if (data.result === 'activate_audio') {
-                console.log('activate_audio');
-                stopVisualiseAudio();
-
-                audio.volume = 0.25;
-                audio_volume_control.value = 25;
-                audio.src = "";
-                audio.currentTime = 0;
-                audio.srcObject = null;
-                audio.src = local_host_sound_route + current_station;
-                audio.load();
-                audio.play();
-
-                if (!spectrumAnalyserActive) {
-                    analyserRandom = Math.round(Math.random() * 1 + 1);
-                    //  analyserRandom = getRandomIntInclusive(1,2);
-                    visualiseAudio(null);
-                    spectrumAnalyserActive = true;
-                }
-            }
-            ;
-
-        });
-
+        }
 
     });
 
-    function updateDisplay() {
-        var req;
-
-        req = $.ajax({
-            type: 'GET',
-            url: "/display_info",
-            cache: false
-        });
-
-        req.done(function (data) {
-            var displays = '';
-            var display = '';
-            var table_id = '';
-            var title = '';
-
-            displays = data.result.split(",");
-
-            $.each(displays, function (idx, val) {
-                display = val;
-
-                if (display.length !== 0) {
-
-                    display = val.split("=");
-                    table_id = display[0];
-                    title = display[1];
-                    if (title !== 'Null') {
-                        $('#Display_' + table_id).attr("value", title);
-                    }
-                    if (title === 'Null') {
-                        $('#Display_' + table_id).attr("value", '');
-                    }
-                    // console.log(title)
-
-                }
-
-            });
-
-        });
-
-
-    }
-    ;
-
-    function updateMasterprogress() {
-        var req;
-
-        req = $.ajax({
-            type: 'POST',
-            url: "/index_posts_percent",
-            cache: false,
-            data: { 'percent': 'percent' }
-        });
-
-        req.done(function (data) {
-            var percent = '';
-
-            percent = data.result;
-            // console.log('########### '+percent+' #########');
-            if (percent === 0) {
-                $('.progress-bar').css('width', 25 + '%').attr('aria-valuenow', 25).html('Timer Off');
-            }
-            if (percent !== 0) {
-                $('.progress-bar').css('width', percent + '%').attr('aria-valuenow', percent).html('Run, Forrest! RUN!');
-                if (percent >= 100) {
-                    window.location.href = "/page_flash";
-                }
-            }
-
-        });
-
-
-    }
-    ;
-
-    function visualiseAudio(var_canvas) {
-
-        // const canvas = document.getElementById("canvas_" + var_canvas);
-        // console.log('show canvas: ' + var_canvas)
-        canvas_ctx = canvas.getContext('2d');
-        requestIdAnimationFrame = undefined;
-
-        let barHeight;
-        let x = 0;
-
-        try {
-            if (analyserRandom === 1) { rotateVisualiser();}
-            if (analyserRandom === 2) { draw();}
-            // if (analyserRandom === 3) { animate();}
-        } catch (error) {console.error(error);}
-
-    }
-    ;
-
-    function stopVisualiseAudio() {
-       try {
-            window.cancelAnimationFrame(requestIdAnimationFrame);
-       } catch (error) {console.error(error);}
-       requestIdAnimationFrame = undefined;
-       spectrumAnalyserActive = false;
-    }
-    ;
-
-    // animate();
-    function animate() {
-        if (!spectrumAnalyserShow) {
-            spectrumAnalyserActive = false;
-            return;
-        }
-        x = 0;
-        analyser.fftSize = 128;
-        const bufferLength = analyser.frequencyBinCount;
-        var barWidth = (canvas.width / bufferLength) * 2; // const barWidth = (canvas.width/2) / bufferLength;
-        const dataArray = new Uint8Array(bufferLength);
-
-        analyser.getByteFrequencyData(dataArray);
-        canvas_ctx.clearRect(0, 0, canvas.width, canvas.height);
-        requestIdAnimationFrame = requestAnimationFrame(animate);
-
-        for (let i = 0; i < bufferLength; i++){
-            barHeight = (dataArray[i] / 2) + 2;
-            let darkBody = getBodyColor(); 
-            if (darkBody) {
-                canvas_ctx.fillStyle = 'red';  //  #d441fc
-                canvas_ctx.fillRect(x, canvas.height - barHeight - 3, barWidth, 18);
-                canvas_ctx.fillStyle = 'rgb(219, 111, 52)';  //  #d441fc
-                canvas_ctx.fillRect(x, canvas.height - barHeight - 6, barWidth, 2);
-                canvas_ctx.fillStyle = 'blue';
-                canvas_ctx.fillRect(x, canvas.height - barHeight, barWidth, barHeight);
-            } else {
-                canvas_ctx.fillStyle = '#bc5090';  //  #d441fc
-                canvas_ctx.fillRect(x, canvas.height - barHeight - 3, barWidth, 18);
-                canvas_ctx.fillStyle = 'black';  //  #d441fc
-                canvas_ctx.fillRect(x, canvas.height - barHeight - 6, barWidth, 2);
-                canvas_ctx.fillStyle = '#565454';
-                canvas_ctx.fillRect(x, canvas.height - barHeight, barWidth, barHeight);
-            }
-
-            x += barWidth;
-
-        }
-    };
-
-    // draw();
-    function draw() {
-        if (!spectrumAnalyserShow) {
-            spectrumAnalyserActive = false;
-            return;
-        }
-        requestIdAnimationFrame = requestAnimationFrame(draw);
-        analyser.fftSize = 2048;
-        const bufferLength = analyser.frequencyBinCount;
-        const dataArray = new Uint8Array(bufferLength);
-        analyser.getByteTimeDomainData(dataArray);
-
-        canvas_ctx.clearRect(0, 0, canvas.width, canvas.height);
-        let darkBody = getBodyColor();
-        if (darkBody) {
-            canvas_ctx.lineWidth = 1.5;
-            canvas_ctx.strokeStyle = 'rgb(219, 111, 52)';
-        } else {
-            canvas_ctx.lineWidth = 1.0;
-            canvas_ctx.strokeStyle = 'red';
-        }
-        canvas_ctx.beginPath();
-        var sliceWidth = canvas.width * 1.0 / bufferLength;
-        var x = 0;
-
-        for (var i = 0; i < bufferLength; i++) {
-            var v = dataArray[i] / 128.0;
-            var y = v * canvas.height / 2;
-
-            if (i === 0) {
-                canvas_ctx.moveTo(x, y);
-            } else {
-                canvas_ctx.lineTo(x, y);
-            }
-
-            x += sliceWidth;
-        }
-
-        canvas_ctx.lineTo(canvas.width, canvas.height / 2);
-        canvas_ctx.stroke();
-    };
-
-    // rotateVisualiser();
-    function rotateVisualiser() {
-        if (!spectrumAnalyserShow) {
-            spectrumAnalyserActive = false;
-            return;
-        }
-        let div_canvas = document.getElementById('div_canvas_master');
-        analyser.fftSize = 128;
-        const bufferLength = analyser.frequencyBinCount;
-        var barWidth = (canvas.width / bufferLength) * 2; // const barWidth = (canvas.width/2) / bufferLength;
-        const dataArray = new Uint8Array(bufferLength);
-        barWidth = (canvas.width/2) / bufferLength;
-        requestIdAnimationFrame = requestAnimationFrame(rotateVisualiser);
-
-        x = 0;
-        analyser.getByteFrequencyData(dataArray);
-        canvas_ctx.clearRect(0, 0, canvas.width, canvas.height);
-        for (let i = 0; i < bufferLength; i++){
-            barHeight = dataArray[i] * 0.36;
-            canvas_ctx.save();
-            let darkBody = getBodyColor();
-            // if (!darkBody) {
-            //     canvas.style.background = "black";
-            // } else {
-            //     canvas.style.background = "rgba(26,26,26,1)";
-            // }
-            canvas_ctx.translate(canvas.width/2, canvas.height/2);
-            canvas_ctx.rotate(i * Math.PI * 4 / bufferLength);
-            const hue = i * 5;
-            canvas_ctx.fillStyle = 'hsl(' + hue + ',100%,50%)';
-            canvas_ctx.fillRect(0, 0, barWidth, barHeight);
-            x += barWidth;
-            canvas_ctx.restore();
-        }
-    };
-    
-    
-}); /* doc.window */
 
+}
+;
 
 function setDarkmode() {
     let req;
@@ -603,14 +220,15 @@ function cookie_get_station() {
                 let station = play_station[0];
                 let station_id = play_station[1];
 
-                document.getElementById('lbl_div_audio').innerText = station; /*station.substring(0, 20)*/
-                document.getElementById('lbl_div_audio').setAttribute("id", "lbl_div_audio");
+                document.getElementById('currentRadioName').innerText = station; /*station.substring(0, 20)*/
+                document.getElementById('currentRadioName').setAttribute("id", "currentRadioName");
 
-                document.getElementById('lbl_div_audio').style.cursor = "pointer";
-                document.getElementById('lbl_div_audio').style.cursor = "hand";
-                $("#lbl_div_audio").on('click', function () {
+                document.getElementById('currentRadioName').style.cursor = "pointer";
+                document.getElementById('currentRadioName').style.cursor = "hand";
+                $("#currentRadioName").on('click', function () {
                     document.getElementById('dot_' + station_id).scrollIntoView({ behavior: "smooth" });
                 });
+                currentRadio = station;
             }/* if */
         }
 
@@ -725,26 +343,25 @@ function cookie_toggle_show_visuals() {
     });
 
     req.done(function (data) {
-        let analyzer_badge = document.getElementById('analyzer_badge');
-        let canvas = document.getElementById('canvas_master');
-        let div_canvas = document.getElementById('div_canvas_master');
+        let analyserBadge = document.getElementById('analyserBadge');
+        let canvasMaster = document.getElementById('canvasMaster');
+        let DivCanvasMaster = document.getElementById('DivCanvasMaster');
         let show_visuals = data.str_visuals;
-        if (show_visuals !== 'show_visuals') {            analyzer_badge.textContent = "hide";
-            canvas.style.display = "inline-block";
-            div_canvas.style.display = "inline-block";
+        if (show_visuals !== 'show_visuals') {
+            analyserBadge.textContent = "hide";
+            canvasMaster.style.display = "inline-block";
+            DivCanvasMaster.style.display = "inline-block";
             cookie_set_show_visuals();
 
-            var ctx = canvas.getContext("2d");
+            var ctx = canvasMaster.getContext("2d");
             ctx.font = "16px Arial";
             ctx.fillStyle = "rgb(219, 111, 52)";
-            ctx.fillText("reload page to activate analyser",10,50);
-
-
+            ctx.fillText("reload page to activate analyser", 10, 50);
         }
         if (show_visuals === 'show_visuals') {
-            analyzer_badge.textContent = "show";
-            canvas.style.display = "none";
-            div_canvas.style.display = "none";
+            analyserBadge.textContent = "show";
+            canvasMaster.style.display = "none";
+            DivCanvasMaster.style.display = "none";
             cookie_del_show_visuals();
 
         }
@@ -764,28 +381,27 @@ function cookie_start_set_text_show_visuals() {
     });
 
     req.done(function (data) {
-        let analyzer_badge = document.getElementById('analyzer_badge');
-        let div_canvas = document.getElementById('div_canvas_master');
-        let canvas = document.getElementById('canvas_master');
+        let analyserBadge = document.getElementById('analyserBadge');
+        let DivCanvasMaster = document.getElementById('DivCanvasMaster');
+        let canvasMaster = document.getElementById('canvasMaster');
         let show_visuals = data.str_visuals;
         if (show_visuals === 'show_visuals') {
-            analyzer_badge.textContent = "hide";
-            canvas.style.display = "inline-block";
-            div_canvas.style.display = "inline-block";
+            analyserBadge.textContent = "hide";
+            canvasMaster.style.display = "inline-block";
+            DivCanvasMaster.style.display = "inline-block";
             spectrumAnalyserShow = true;
-            if (!spectrumAnalyserActive) {
-                var ctx = canvas.getContext("2d");
-                ctx.font = "16px Arial";
-                ctx.fillStyle = "rgb(219, 111, 52)";
-                ctx.fillText("change radio to activate analyser",10,50);
 
-            }
+            var ctx = canvasMaster.getContext("2d");
+            ctx.font = "14px Arial";
+            ctx.fillStyle = "rgb(219, 111, 52)";
+            ctx.fillText("select a radio to activate analyser", 10, 50);
+
 
         }
         if (show_visuals !== 'show_visuals') {
-            analyzer_badge.textContent = "show";
-            canvas.style.display = "none";
-            div_canvas.style.display = "none";
+            analyserBadge.textContent = "show";
+            canvasMaster.style.display = "none";
+            DivCanvasMaster.style.display = "none";
             spectrumAnalyserShow = false;
         }
 
@@ -795,16 +411,13 @@ function cookie_start_set_text_show_visuals() {
 }
 ;
 
-
-
-
 function setTimer(val) {
 
     $.ajax({
         type: 'POST',
         url: "/index_posts_combo",
         cache: false,
-        data: { 'time_record_select_all': val }
+        data: { 'timeRecordSelectAll': val }
 
     });
 }
@@ -851,7 +464,7 @@ function setColor(val) {
             bodyStyles.setProperty('--ghetto-measurements-bottom-color', '#FCA841');
             bodyStyles.setProperty('--radio-station-headline', '#4195fc');
             bodyStyles.setProperty('--controls-background', 'rgba(26,26,26,1)');
-            bodyStyles.setProperty('--canvas_master', 'rgba(26,26,26,0.85)');
+            bodyStyles.setProperty('--canvasMaster', 'rgba(26,26,26,0.85)');
 
             setDarkmode();
         }
@@ -872,7 +485,7 @@ function setColor(val) {
             bodyStyles.setProperty('--ghetto-measurements-bottom-color', '#d441fc');
             bodyStyles.setProperty('--radio-station-headline', '#565454');
             bodyStyles.setProperty('--controls-background', '#565454');
-            bodyStyles.setProperty('--canvas_master', '#ccc');    // rgba(240, 240, 240, 0.85)
+            bodyStyles.setProperty('--canvasMaster', '#ccc');    // rgba(240, 240, 240, 0.85)
 
             delDarkmode();
         }
@@ -907,6 +520,7 @@ function meta_info() {
                 let response_time = val[0];
                 let suffix = val[1];
                 let genre = val[2];
+                currentRadioGenre = genre;
                 let station_name = val[3];
                 let station_id = val[4];
                 let bit_rate = val[5];
@@ -941,6 +555,7 @@ function delete_info() {
             $.each(stopped_list, function (idx, val) {
 
                 let station_id = val;
+                document.getElementById('Display_' + station_id).value = "";
                 document.getElementById('request_time_' + station_id).innerText = "";
                 document.getElementById('request_suffix_' + station_id).innerText = "";
                 document.getElementById('request_icy_br_' + station_id).innerText = "";
@@ -994,7 +609,7 @@ function _base64ToArrayBuffer(base64) {
 ;
 
 update_file_list = function () {
-    var input = document.getElementById('fileupload');
+    var input = document.getElementById('fileUpload');
     var output = document.getElementById('file_list');
     var children = "";
     for (let i = 0; i < input.files.length; ++i) {
@@ -1022,7 +637,7 @@ function shuffle_array(array) {
 /**
  *  calculateMediaDuration()
  *  Force media element duration calculation.
- *  Returns a promise, that resolves when duration is calculated
+ *  Returns a promise, that resolves when duration is calculated; needed for aacp broken time lines, not working so far
  **/
 function calculateMediaDuration(media) {
     return new Promise((resolve, reject) => {
@@ -1046,19 +661,253 @@ function calculateMediaDuration(media) {
 function getBodyColor() {
     let bodyStyle = window.getComputedStyle(document.body, null);
     let backgroundColor = bodyStyle.backgroundColor;
+    let darkBody;
     if (backgroundColor === 'rgb(26, 26, 26)') {
-        var darkBody = true;
+        darkBody = true;
     } else { darkBody = false; }
     return darkBody;
 }
 ;
 
 function getRandomIntInclusive(min, max) {
-  min = Math.ceil(min);
-  max = Math.floor(max);
-  return Math.floor(Math.random() * (max - min +1)) + min;
+    min = Math.ceil(min);
+    max = Math.floor(max);
+    return Math.floor(Math.random() * (max - min + 1)) + min;
 }
 ;
 
+$(document).ready(function () {
+
+    document.getElementById('pageCover').addEventListener('click', removePageCover);
+    pageCoverAnimation();
+
+    $('[data-toggle="tooltip"]').tooltip()
+    cookieStuff();
+    cookie_start_set_text_show_visuals();
+    setInterval(delete_info, 2505);
+    setInterval(meta_info, 5004);
+    setInterval(toggle_show_select_box, 5003);
+    setInterval(updateMasterprogress, 5002);
+    setInterval(updateDisplay, 5001);
+    audio.volume = 0.25;     // after page reload
+
+    audio.addEventListener("play", function () {
+        playBtn.style.display = "none";
+        pauseBtn.style.display = "block";
+        pauseBtn.style.cursor = "pointer";
+        pauseBtn.style.cursor = "hand";
+        $("#pauseBtn").on('click', function () {
+            audio.pause();
+        });
+    });
+    audio.addEventListener("pause", function () {
+        playBtn.style.display = "block";
+        pauseBtn.style.display = "none";
+        playBtn.style.cursor = "pointer";
+        playBtn.style.cursor = "hand";
+        $("#playBtn").on('click', function () {
+            audio.play();
+        });
+    });
+
+    audioVolumeController.addEventListener("input", setAudioVolume);
+    audioGainController.addEventListener("input", setAudioGain);
+
+    // local audio
+    fileUpload.addEventListener("change", function () {
+        var audio_duration;
+
+        stopVisualise();
+
+        const playlist_title = document.getElementById("playlist_title");
+        const playlist_section = document.getElementById("playlist_section");
+        playlist_title.style.display = "block";
+        playlist_section.style.display = "block";
+
+        document.getElementById('currentRadioName').innerText = "local playlist"; /*currentRadioName.substring(0, 20)*/
+        document.getElementById('currentRadioName').style.cursor = "pointer";
+        document.getElementById('currentRadioName').style.cursor = "hand";
+        $("#currentRadioName").on('click', function () {
+            document.getElementById('file_list').scrollIntoView({ behavior: "smooth" });
+        });
+
+        // console.log(this.files);
+        const files = this.files;
+
+        const clone_files = [...files];
+        const audio = document.getElementById("audioWithControls");
+        const checkbox_shuffle = document.getElementById('checkbox_shuffle');
+        var fileList = [];
+        for (let i = 0; i < fileUpload.files.length; i++) {
+            fileList.push(fileUpload.files[i]);
+        }
+        var play_list;
+        play_list = fileList // for non shuffled
+        if (checkbox_shuffle.checked) {
+            // play_list = shuffle_array(fileList);    // destroys fileList org.
+            play_list = shuffle_array(clone_files);
+        }
+        audio.src = URL.createObjectURL(play_list[0]);
+        playlist_title.value = play_list[0].name;
+
+        /*
+    calculateMediaDuration(audio).then(() => {
+        console.log(audio.duration);
+    });
+    */
+        let isPlayList = false;
+        reloadAudioElement(audio.src, isPlayList);
+        // setTimeout(() => {
+        //     audio.pause();
+        //     audio.currentTime = Number.MAX_SAFE_INTEGER; // chrome bug; NaN, infinity
+        // }, audio_duration);
+
+        let track = 1;
+        audio.onended = function () {
+            if (track < play_list.length) {
+
+                audio.src = URL.createObjectURL(play_list[track]);
+                playlist_title.value = play_list[track].name;
+                stopVisualise();
+                let isPlayList = true;
+                reloadAudioElement(audio.src, isPlayList);
+
+                track++;
+            }
+        }
+
+    });  // file_up
+
+
+    $("button").click(function () {
+
+        if ($(this).attr("class") === "navbar-toggle collapsed") {
+
+            return;
+        }
+        ;
+
+        let clicked = $(this).attr("name");
+        console.log("send name " + clicked);
+        let class_val = $(this).attr("class");
+        console.log("send button " + class_val);
+        let id = $(this).attr("id");
+        let dict = {
+            'name': clicked,
+            'class_val': class_val,
+            'button_id': id
+
+        };
+        req = $.ajax({
+            type: 'POST',
+            dataType: "json",
+            url: "/",
+            data: dict
+        });
+        $('#' + id).fadeOut(1).fadeIn(3);
+
+        req.done(function (data) {
+
+            if (data.class_val === "btn btn-primary") {
+                $('#' + id).removeClass("btn btn-primary");
+                $('#' + id).addClass("btn btn-danger");
+            }
+            ;
+
+            if (data.class_val === "btn btn-danger") {
+                $('#' + id).removeClass("btn btn-danger");
+                $('#' + id).addClass("btn btn-primary");
+            }
+            ;
+
+            if (data.streamer) {
+                /* Del all streamer, push current in combo box */
+                cookie_set_streamer();
+                $('#cacheList').find('option:not(:first)').remove();
+                let streamer = data.streamer.split(",");
+
+                $.each(streamer, function (idx, val) {
+
+                    let stream = val;
+                    if (stream.length !== 0) {
+                        stream = val.split("=");
+                        let table_id = stream[1];
+                        let title = stream[0];
+                        cacheListFeed(table_id, title);
+
+                        if (data.streamer === 'empty_json') {
+                            $('#cacheList').find('option:not(:first)').remove();
+                            document.getElementById('cacheList').style.color = "#696969";
+                            document.getElementById('cacheList').style.textColor = "#696969";
+                            cookie_del_streamer();
+                        }
+                        console.log('data.streamer ' + data.streamer);
+
+                    }
+
+                });    /*each*/
+
+            }
+            ;
+
+            if (data.radio_table_id) {
+
+            }
+            ;
+
+            /* current play station */
+
+            if (data.table_ident) {
+
+                var currentRadioName = data.table_ident;
+                console.log('table_ident ' + currentRadioName);
+
+                if (currentRadioName !== 'Null') {
+
+                    cookie_set_station(currentRadioName, id);
+
+                    document.getElementById('currentRadioName').innerText = currentRadioName; /*currentRadioName.substring(0, 20)*/
+                    document.getElementById('currentRadioName').style.cursor = "pointer";
+                    document.getElementById('currentRadioName').style.cursor = "hand";
+                    $("#currentRadioName").on('click', function () {
+                        document.getElementById('dot_' + id).scrollIntoView({ behavior: "smooth" });
+                    });
+
+                }
+                if (data.former_button_to_switch) {
+                    let num = data.former_button_to_switch;
+                    console.log('auto_click former_button_to_switch: ' + num);
+                    $("#" + num).click();
+                }
+                ;
+            }
+            ;
+
+            if (data.result === 'deactivate_audio') {
+                console.log('deactivate_audio');
+                audio.src = "";
+                audio.currentTime = 0;
+                audio.srcObject = null;
+                document.getElementById('currentRadioName').innerText = '';
+                cookie_del_station();
+            }
+            ;
+
+            if (data.result === 'activate_audio') {
+                console.log('activate_audio');
+                stopVisualise();
+
+                let newSource = localHostSoundRoute + currentRadioName;
+                let isPlayList = false;
+                reloadAudioElement(newSource, isPlayList);
+            }
+            ;
+
+        });
+
+
+    });
+
+}); /* doc.window */
 
 
