@@ -25,16 +25,6 @@ listen_last_url = None
 combo_master_timer = 0
 progress_master_percent = 0
 
-active_displays = {}
-eisen_threads = []
-
-
-def enum_radios():
-    conn = get_db_connection()
-    posts = conn.execute('SELECT * FROM posts').fetchall()
-    conn.close()
-    return posts
-
 
 def index_first_run(posts):
     global first_run_index
@@ -47,8 +37,14 @@ def index_first_run(posts):
             # init btn not pressed
             status_listen_btn_dict[row['id']] = 0
             status_record_btn_dict[row['id']] = 0
-            # api
-            radios_in_view_dict[row['id']] = status_read_status_set(False, 'posts', 'title', row['id'])
+
+        feed_radios_in_view_dict(posts)
+
+
+def feed_radios_in_view_dict(posts):
+    for row in posts:
+        # api
+        radios_in_view_dict[row['id']] = status_read_status_set(False, 'posts', 'title', row['id'])
 
 
 def curr_radio_listen():
@@ -226,7 +222,6 @@ def dispatch_recorder_stop(table_id):
     # stop recorder threads
     ghetto.GBase.dict_exit[str_radio] = True
     try:
-        del active_displays[table_id]
         sleep(2)
         if status_listen_btn_dict[table_id]:
             dispatch_record_title(table_id, False, True)
@@ -240,90 +235,33 @@ def dispatch_record_title(table_id, record, listen):
     str_url = status_read_status_set(False, 'posts', 'content', table_id)
 
     ghetto.GBase.dict_exit[str_radio] = False
+
     # test for alive, container docker or snap, and playlist / data_base_auto
     str_checked_url_m3u = ghetto.check_alive_playlist_container(str_radio, str_url)
     if str_checked_url_m3u:
         # replace m3u with real url in database
         conn = get_db_connection()
-        print('UPDATE posts SET content = ? WHERE id = ?', (str(str_checked_url_m3u), str(table_id)))
+        # print('UPDATE posts SET content = ? WHERE id = ?', (str(str_checked_url_m3u), str(table_id)))
         conn.execute('UPDATE posts SET content = ? WHERE id = ?', (str(str_checked_url_m3u), str(table_id)))
         conn.commit()
         conn.close()
         str_url = str_checked_url_m3u
+
     try:
         print(ghetto.GBase.dict_error[str_radio])  # show connection error in display
     except KeyError:
         # no error, no key exists
-        """ ghetto.record starts all """
+        """ ghetto.record starts all radio relevant threats"""
         if record:
             ghetto.record(str_radio=str_radio, url=str_url, str_action='record')
         if listen:
             ghetto.record(str_radio=str_radio, url=str_url, str_action='listen')
-
-        thread = threading.Thread(name=str_radio, target=display_write_db, args=(str_radio, table_id), daemon=True)
-        # eisen_threads.append(thread)
-        thread.start()
         return True
     else:
-        """show error on display"""
-        active_displays[table_id] = ghetto.GBase.dict_error[str_radio]
         ghetto.GBase.dict_exit[str_radio] = True
         return False
 
 
-def display_write_dict():
-
-    conn = get_db_connection()
-    try:
-        titles = conn.execute('SELECT id, display FROM posts').fetchall()
-        for row in titles:
-            table_id = row[0]
-            title = row[1]
-            if title is not None:
-                active_displays[table_id] = title
-    except KeyError:
-        pass
-    conn.close()
-
-
-def display_write_db(radio, table_id):  # title "britney pierced - dump it"; other thread can collect or pull it or else
-    title = ''
-    while 1:
-
-        try:
-            title = ghetto.GRecorder.current_song_dict[radio]
-        except KeyError:
-            pass
-        display_update_table(title, table_id)
-        try:
-            display_update_table(title, table_id)
-        except Exception as e:
-            print(e)
-            pass
-
-        for sec in range(5):
-            sleep(1)
-            if ghetto.GBase.dict_exit[radio]:
-                title = 'Null'
-                display_update_table(title, table_id)
-                break
-        if ghetto.GBase.dict_exit[radio]:
-            break
-
-
-def display_update_table(title, table_id):
-
-    conn = get_db_connection()
-    try:
-        conn.execute('UPDATE posts SET display = ? WHERE id = ? ;', (str(title), str(table_id)))   # parameter tuple
-    except Exception as e:
-        print(f' utf char prob. check lang. support display_update_table(): {e}')
-    else:
-        conn.commit()
-        conn.close()
-        display_write_dict()
-
-
 def display_clean_titles():
     conn = get_db_connection()
     records = conn.execute('select id from posts').fetchall()
