@@ -1,7 +1,7 @@
 from flask import Blueprint, render_template, request, flash, redirect, url_for, make_response, jsonify
 
 import eisenradio.eisenhome.eishome as eisen_radio
-from eisenradio.lib.eisdb import get_post, delete_radio
+from eisenradio.lib.eisdb import get_post, delete_radio, enum_radios
 from eisenradio.api import ghettoApi
 
 local_host_sound_route = "http://localhost:5050/sound/"
@@ -22,7 +22,7 @@ def index():
 
     if eisen_radio.first_run_index:
         eisen_radio.check_write_protected()
-    posts = eisen_radio.enum_radios()
+    posts = enum_radios()
     eisen_radio.display_clean_titles()
     eisen_radio.index_first_run(posts)
     current_station, current_table_id = eisen_radio.curr_radio_listen()
@@ -188,7 +188,7 @@ def cookie_del_show_visuals():
 
 @eisenhome_bp.route('/index_posts_combo', methods=['POST'])
 def index_posts_combo():
-    eisen_radio.combo_master_timer = request.form['time_record_select_all']
+    eisen_radio.combo_master_timer = request.form['timeRecordSelectAll']
     return eisen_radio.combo_master_timer
 
 
@@ -197,23 +197,23 @@ def index_posts_percent():
     return jsonify({'result': eisen_radio.progress_master_percent})
 
 
-@eisenhome_bp.route('/display_info', methods=('GET', 'POST'))
+@eisenhome_bp.route('/display_info', methods=['GET'])
 def display_info():
     """updateDisplay() ajax"""
     if request.method == "GET":
-        json_str = ''
-        dict_display = {}
-        for val in eisen_radio.active_displays:
-            json_str = json_str + str(val) + '=' + str(eisen_radio.active_displays[val]) + ','
-            dict_display[str(val)] = str(eisen_radio.active_displays[val])
-        return jsonify({"result": json_str})     # dict_display
+        id_text_dict = {}
+        try:
+            for radio_name, radio_text in ghettoApi.ghetto_radios_metadata_text.items():
+                for radio_db_id, radio_title in ghettoApi.radios_in_view_dict.items():
+                    if radio_name == radio_title:
+                        if len(radio_text) > 0:
+                            id_text_dict[str(radio_db_id)] = str(radio_text)
 
+            for radio_name, radio_error in ghettoApi.ghetto_dict_error.items():
+                for radio_db_id, radio_title in ghettoApi.radios_in_view_dict.items():
+                    if radio_name == radio_title:
+                        id_text_dict[str(radio_db_id)] = str(radio_error)
+        except Exception as error:
+            print(f'display_info: {error}')
 
-@eisenhome_bp.route('/is_play_station', methods=['GET'])
-def is_play_station():
-    current_station, current_table_id = eisen_radio.curr_radio_listen()
-    if not current_station:
-        current_station = '-empty-'
-        current_table_id = '-empty-'
-
-    return jsonify({'is_play_station_id': str(current_table_id), 'is_play_station_name': current_station})
+        return jsonify({"result": id_text_dict})
