@@ -1,9 +1,9 @@
 import configparser
 from os import path
 from flask import flash
-from eisenradio.lib.eisdb import delete_radio, get_db_connection, get_db_smaller, get_db_path, status_read_status_set
+from eisenradio.lib.eisdb import delete_radio, get_db_connection, get_db_smaller, status_read_status_set
 from eisenradio.eisenutil.eisutil import is_in_db_view
-from eisenradio.lib.eisdb import render_picture
+from eisenradio.lib.eisdb import render_picture, get_download_dir
 
 
 def delete_all_radios():
@@ -26,10 +26,7 @@ def export_radios():
     # BLUES_UK = http://149.255.59.3:8232/stream
     rv = True
     radio_url_dict = {}
-
-    db_path = get_db_path()
     download_path = ''
-    export_path = path.abspath(path.dirname(db_path))
 
     try:
         posts = get_radios()
@@ -43,6 +40,11 @@ def export_radios():
     except ValueError:
         rv = False
 
+    if not rv:
+        return rv
+
+    export_path = download_path
+
     try:
         with open(path.join(export_path, 'settings.ini'), 'w') as writer:
             writer.write('[GLOBAL]' + '\n')
@@ -50,17 +52,39 @@ def export_radios():
             writer.write('[STATIONS]' + '\n')
             for radio, url in radio_url_dict.items():
                 writer.write(radio + ' = ' + url + '\n')
-                writer.flush()
+            writer.flush()
     except OSError:
         rv = False
     return rv
 
 
-def import_radios(path_ini):
-    ini_dict = find_all_in_stations(path_ini)
+def upload_radios(str_ini):    # entry point for an uploaded ini
+    config = configparser.ConfigParser()
+    global_dict = False
+    station_dict = False
+    try:
+        config.read_string(str_ini)
+        station_dict = config['STATIONS']
+        global_dict = config['GLOBAL']
+        if len(global_dict) == 0:
+            global_dict = False
+    except Exception as error:
+        print(f' upload_radios unknown error: {error} - but will proceed')
+    finally:
+        if not station_dict:
+            print(f' error in [STATIONS]')
+            return False
+        rv = db_import_ini(station_dict, global_dict, None)
+        if rv:
+            return True
+        return False
 
-    if ini_dict:
-        rv = db_import_ini(ini_dict, path_ini)
+
+def import_radios(path_ini):    # entry point for a normal input field: path
+    station_dict = find_all_in_stations(path_ini)
+
+    if station_dict:
+        rv = db_import_ini(station_dict, None, path_ini)
         if rv:
             return True
     return False
@@ -90,36 +114,38 @@ def find_save_to_dir(path_ini):
         return global_dict
 
 
-def db_import_ini(ini_dict, path_ini):
+def db_import_ini(station_dict, global_dict=None, path_ini=None):
     download_path = ''
     conn = get_db_connection()
     posts = conn.execute('SELECT * FROM posts').fetchall()
 
-    for key, value in ini_dict.items():
-        title = key
-        content = value
+    """all radios with url from ini file, station section"""
+    for title, content in station_dict.items():
 
-        i = 1
-        search_str = title
-        while is_in_db_view(search_str):
-
-            if not is_in_db_view(search_str + '__' + str(i)):
-                title = search_str + '__' + str(i)
-                break
-            i += i
+        if is_in_db_view(title):
+            title = title + '__duplicated_name'
 
         radio_image, content_type = radio_spare_image()
-        # if we later want extra save folders for each radio
+
         try:
             download_path = posts[0]["download_path"]
         except IndexError:
-            global_dict = find_save_to_dir(path_ini)
+            if not global_dict:
+                # 'Section Header, but no content.'
+                conn.execute('INSERT INTO posts (title, content, download_path, pic_data, pic_content_type) VALUES ('
+                             '?, ?, ?, ?, ?)',
+                             (title, content, '/use/Save/from/menu', radio_image, content_type))
             if global_dict:
                 download_path = global_dict['SAVE_TO_DIR']
+            if path_ini:
+                global_dict = find_save_to_dir(path_ini)
+                if global_dict:
+                    download_path = global_dict['SAVE_TO_DIR']
         except KeyError:
             print(' looks like the first radio to create, no save to path set')
-            conn.execute('INSERT INTO posts (title, content, pic_data, pic_content_type) VALUES (?, ?, ?, ?)',
-                         (title, content, radio_image, content_type))
+            conn.execute('INSERT INTO posts (title, content, download_path, pic_data, pic_content_type) VALUES ('
+                         '?, ?, ?, ?, ?)',
+                         (title, content, '/use/Save/from/menu', radio_image, content_type))
         try:
             if download_path:
                 conn.execute('INSERT INTO posts (title, content, download_path, pic_data, pic_content_type) VALUES ('
@@ -128,6 +154,7 @@ def db_import_ini(ini_dict, path_ini):
         except ValueError:
             conn.close()
             return False
+
     conn.commit()
     conn.close()
     return True
@@ -148,3 +175,12 @@ def radio_spare_image():
     img_base64 = render_picture(image_bin, 'encode')
     content_type = 'image/png'
     return img_base64, content_type
+
+
+def get_export_path():
+    download_path = get_download_dir()
+    if not download_path:
+        export_path = "use Save from Navigation Menu"
+    else:
+        export_path = download_path
+    return export_path
