@@ -182,3 +182,17 @@ def delete_radio(radio_id):
         return False
     conn.close()
     return True
+
+
+def enum_radios():
+    conn = get_db_connection()
+    posts = conn.execute('SELECT * FROM posts').fetchall()
+    conn.close()
+    return posts
+
+
+def db_get_id_from_name(radio_name):
+    conn = get_db_connection()
+    radio_id = conn.execute('SELECT id FROM posts WHERE title = ?', (str(radio_name),)).fetchone()
+    conn.close()
+    return radio_id[0]
