@@ -40,7 +40,7 @@ from eisenradio.api import ghettoApi
 # logging.basicConfig(level=logging.DEBUG, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
 # logging.basicConfig(level=logging.INFO, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
 
-version = '1.4'
+version = '1.5'
 print(f'ghettorecorder {version} (eisen_radio module)')  # ########## version #############
 
 
@@ -48,7 +48,7 @@ class GBase:
     # class attribute
     dict_exit = {}  # all "single" started (this time four, each station)
     dict_error = {}
-
+    ghettoApi.init_ghetto_dict_error(dict_error)
     sleeper = 2  # for exit of all threads
     pool = ThreadPoolExecutor(200)
     radio_base_dir = os.path.dirname(os.path.abspath(__file__)) + '//radiostations'  # if not set set_radio_base_dir()
@@ -137,14 +137,19 @@ class GNet(GBase):
         # we have server up, but content not presented - zombie
         try:
             GNet.load_url(url)
-        except HTTPError:
-            print('HTTPError')
-            GBase.dict_error[str_radio] = 'HTTPError - check radio homepage'
+        except HTTPError as error:
+            print(f' ---> {str_radio} server failed: {error} , {url}')
+            GBase.dict_error[str_radio] = f'{str_radio} radio: {error} {url}'
             return True
         except URLError as error:  # <urlopen error timed out>
             print(f' ---> {str_radio} server failed: {error} , {url}')
-            GBase.dict_error[str_radio] = error
-            print('URLError')
+            GBase.dict_error[str_radio] = f'{str_radio} radio: {error} {url}'
+            return False
+        except Exception as error:
+            """catch timeout here, real life - stackoverflow is not correct to say part of URLError, 
+            had to update this. Since this is not a thread used def the whole app goes down the drain"""
+            print(f' ---> {str_radio} server exception: {error} , {url}')
+            GBase.dict_error[str_radio] = f'{str_radio} radio: {error} {url}'
             return False
         return True
 
@@ -186,6 +191,7 @@ class GRecorder:
     unknown_title_name = 'unknown_title'
     path_record_dict = {}  # {station : file path}
     current_song_dict = {}  # each thread writes the new title to the station key name {station : title}
+    ghettoApi.init_ghetto_radios_metadata_text(current_song_dict)
     start_write_command = {}  # recorder head thread set command to copy first file
     search_pattern_found = {}
 
@@ -417,10 +423,16 @@ class GRecorder:
         try:
             with urllib.request.urlopen(url, timeout=15) as response:
                 bit_rate = response.getheader('icy-br')
-                return bit_rate
+                try:
+                    if int(bit_rate) % 1 == 0:
+                        return bit_rate
+                except ValueError:
+                    # got server with '128,128'
+                    print(f'g_recorder_ask_bit_rate ValueError: {bit_rate} {url}')
+                    return 320
         except Exception as ex:
             print(ex)
-            return False
+            return 320
 
     @staticmethod
     def g_recorder_calc_chunk_size(url):
@@ -491,13 +503,25 @@ class GRecorder:
     def metadata_header_info(request, str_radio, request_time):
         try:
             GRecorder.ghetto_measure[str_radio + ',request_time'] = request_time
+        except KeyError:
+            pass
+        try:
             GRecorder.ghetto_measure[str_radio + ',suffix'] = request.headers['content-type']
         except KeyError:
             pass
         try:
-            GRecorder.ghetto_measure[str_radio + ",icy_genre"] = request.headers["icy-genre"]
-            GRecorder.ghetto_measure[str_radio + ",icy_name"] = request.headers["icy-name"]
             GRecorder.ghetto_measure[str_radio + ",icy_br"] = request.headers["icy-br"]
+        except KeyError:
+            pass
+        try:
+            GRecorder.ghetto_measure[str_radio + ",icy_name"] = request.headers["icy-name"]
+        except KeyError:
+            pass
+        try:
+            GRecorder.ghetto_measure[str_radio + ",icy_genre"] = request.headers["icy-genre"]
+        except KeyError:
+            pass
+        try:
             GRecorder.ghetto_measure[str_radio + ",icy_url"] = request.headers["icy-url"]
         except KeyError:
             pass
@@ -545,11 +569,18 @@ class GRecorder:
     @staticmethod
     def metadata_get_display_info(icy_info):
         # <class 'bytes'> decode to <class 'str'> actually b''
-        title = GRecorder.metadata_get_display_extract(icy_info.decode('utf-8'))
-        if not title:
+        try:
+            title = GRecorder.metadata_get_display_extract(icy_info.decode('utf-8'))
+            if not title:
+                return
+            if title:
+                return title
+        except AttributeError:
+            """AttributeError: Server sends no metadata; bool value instead"""
+            return
+        except Exception as error:
+            print(f' Exception in metadata_get_display_info: {error}')
             return
-        if title:
-            return title
 
     @staticmethod
     def get_metadata_from_stream_loop(url, str_radio, str_action):
@@ -568,6 +599,9 @@ class GRecorder:
             except URLError:
                 """url was checked in is_server_alive. assume short conn error"""
                 pass
+            except Exception as error:
+                print(f' ---> get_metadata_from_stream_loop {str_radio}, exception info: {error} , {url}')
+                pass
 
             title = GRecorder.metadata_get_display_info(icy_info)
             if title:
@@ -578,8 +612,8 @@ class GRecorder:
                         GRecorder.current_song_dict[str_radio] = title
                 except KeyError:
                     pass
-                except Exception as e:
-                    print(e)
+                except Exception as error:
+                    print(f' ---> metadata_get_display_info {str_radio}, exception info: {error} , {url}')
                     pass
 
             for sec in range(2):
@@ -593,6 +627,7 @@ class GRecorder:
                         break
                 sleep(1)
             if stop_while:
+                GRecorder.current_song_dict[str_radio] = ""
                 break
 
     @staticmethod
@@ -645,9 +680,9 @@ def check_alive_playlist_container(str_radio, str_url):
 
 
 def record_start_radio(str_radio, url, stream_suffix, dir_save, str_action):
-    threading.Thread(name=str_radio + '_' + str_action + "_show", target=GRecorder.ghetto_recorder_display_title,
-                     args=(str_radio, str_action),
-                     daemon=True).start()
+    # threading.Thread(name=str_radio + '_' + str_action + "_show", target=GRecorder.ghetto_recorder_display_title,
+    #                  args=(str_radio, str_action),
+    #                  daemon=True).start()
     threading.Thread(name=str_radio + '_' + str_action + "_head", target=GRecorder.ghetto_recorder_head,
                      args=(dir_save, stream_suffix, str_radio, str_action),
                      daemon=True).start()
@@ -669,7 +704,7 @@ def record(str_radio, url, str_action):
     # GIni.start_stop_recording[str_radio] = 'stop'   # init it here, checkbox user interface
     GIni.start_stop_recording[str_radio + '_adv'] = 'start_from_here'
 
-    dir_save = GBase.radio_base_dir + '//' + str_radio  # [Baustelle]
+    dir_save = GBase.radio_base_dir + '//' + str_radio    # [Baustelle]
     record_start_radio(str_radio, url, stream_suffix, dir_save, str_action)
 
     # ################################## end ########################################
